Monte-Carlo Fictitious Play
===========================

.. toctree::

   reference_monte_carlo_fictitious_play
   reference_plot_distribution_scores
   reference_plot_utility_thresholds
   reference_plot_welfare_losses
